﻿/*
 * Author: G. Monz (DK7IO), 2012-04-29
 * This file is distributed without any warranty.
 * */

using System;
using System.Globalization;
using System.Diagnostics;
using System.Windows.Forms;

namespace KML2NET
{
	public static class Utilities
	{
		public static Single ParseSingle(TextBoxBase textBoxBase)
		{
			Single result = ParseSingle(textBoxBase.Text);

			return result;
		}

		public static Single ParseSingle(string text)
		{
			Single result = Single.Parse(
				text,
				NumberStyles.Float | NumberStyles.AllowThousands
			);

			return result;
		}

		public static bool TryParseSingle(TextBoxBase textBoxBase)
		{
			bool result;

			try
			{
				Single value = ParseSingle(textBoxBase);
				result = true;
			}
			catch (Exception)
			{
				result = false;
			}

			return result;
		}

		public static Byte ParseByte(TextBoxBase textBoxBase)
		{
			string text = textBoxBase.Text;
			Byte result = Byte.Parse(
				text,
				NumberStyles.Integer
			);

			return result;
		}

		public static bool TryParseByte(TextBoxBase textBoxBase)
		{
			bool result;

			try
			{
				Byte value = ParseByte(textBoxBase);
				result = true;
			}
			catch (Exception)
			{
				result = false;
			}

			return result;
		}

		/// <summary>
		/// Prüft, ob ein <see cref="String" /> null oder ein Leer-<see cref="String" /> ist.
		/// </summary>
		/// <param name="text">Der zu prüfende <see cref="String" />.</param>
		/// <returns>
		/// True, wenn der zu prüfende <see cref="String" /> null oder ein Leer-<see cref="String" /> ist.
		/// Sonst false.
		/// </returns>
		public static bool IsEmpty(string text)
		{
			bool result = string.IsNullOrEmpty(text);

			return result;
		}

		/// <summary>
		/// Prüft, ob ein <see cref="String" /> null oder ein Leer-<see cref="String" /> ist.
		/// </summary>
		/// <param name="text">Der zu prüfende <see cref="String" />.</param>
		/// <param name="trim">
		/// True, wenn vor der Prüfung führende und folgende Leerzeichen abgeschnitten werden sollen.
		/// Sonst false.
		/// </param>
		/// <returns>
		/// True, wenn der zu prüfende <see cref="String" /> null oder ein Leer-<see cref="String" /> ist.
		/// Sonst false.
		/// </returns>
		public static bool IsEmpty(string text, bool trim)
		{
			bool result = true;

			if (!IsEmpty(text))
			{
				result = (
					trim ?
					IsEmpty(text.Trim()) :
					false
				);
			}

			return result;
		}

		public static string TrimText(string text)
		{
			string result = (
				IsEmpty(text) ?
				text :
				text.Trim()
			);

			return result;
		}

		public static Exception StartProcess(string fileName, string arguments, string workingDirectory)
		{
			Exception result = null;

			if (!IsEmpty(fileName, true))
			{
				try
				{
					Process process = new Process();
					{
						ProcessStartInfo processStartInfo = process.StartInfo;
						{
							processStartInfo.FileName = fileName;
							processStartInfo.Arguments = arguments;
							processStartInfo.WorkingDirectory = workingDirectory;
						}

						process.Start();
					}
				}
				catch (Exception ex)
				{
					result = ex;
				}
			}

			return result;
		}
	}
}