﻿/*
 * Author: G. Monz (DK7IO), 2012-04-29
 * This file is distributed without any warranty.
 * */

using System;
using System.IO;
using System.Drawing;

namespace RadioMobile
{
	public enum CoverageThreshold
	{
		S_Unit = 0,
		dBm = 1,
		microV = 2,
		dBmicroVperMeter = 3,
	}

	public class RMCoverage
	{
		Single _radialRangeMinimum = (Single)(0.01);
		public Single RadialRangeMinimum //km
		{
			get
			{
				return _radialRangeMinimum;
			}
			set
			{
				_radialRangeMinimum = value;
			}
		}

		Single _radialRangeMaximum = (Single)(50);
		public Single RadialRangeMaximum //km
		{
			get
			{
				return _radialRangeMaximum;
			}
			set
			{
				_radialRangeMaximum = value;
			}
		}

		Single _azimuthRangeMinimum = (Single)(0);
		public Single AzimuthRangeMinimum //Degrees
		{
			get
			{
				return _azimuthRangeMinimum;
			}
			set
			{
				_azimuthRangeMinimum = value;
			}
		}

		Single _azimuthRangeMaximum = (Single)(360);
		public Single AzimuthRangeMaximum //Degrees
		{
			get
			{
				return _azimuthRangeMaximum;
			}
			set
			{
				_azimuthRangeMaximum = value;
			}
		}

		Single _azimuthRangeStep = (Single)(1);
		public Single AzimuthRangeStep //Degrees
		{
			get
			{
				return _azimuthRangeStep;
			}
			set
			{
				_azimuthRangeStep = value;
			}
		}

		Single _antennaAzimuth = (Single)(0);
		public Single AntennaAzimuth //Degrees
		{
			get
			{
				return _antennaAzimuth;
			}
			set
			{
				_antennaAzimuth = value;
			}
		}

		String _antennaFile = string.Empty;
		public String AntennaFile //Length:=20
		{
			get
			{
				return _antennaFile;
			}
			set
			{
				_antennaFile = value;
			}
		}

		CoverageThreshold _threshold = CoverageThreshold.S_Unit;
		public CoverageThreshold Threshold
		{
			get
			{
				return _threshold;
			}
			set
			{
				_threshold = value;
			}
		}

		Single _level = (Single)(-107);
		public Single Level //dBm
		{
			get
			{
				return _level;
			}
			set
			{
				_level = value;
			}
		}

		bool _fillArea = true;
		public bool FillArea
		{
			get
			{
				return _fillArea;
			}
			set
			{
				_fillArea = value;
			}
		}

		Int32 _areaColor = Utilities.GetColorNumber(255, 255, 0);
		public Int32 AreaColor //0...16777215
		{
			get
			{
				return _areaColor;
			}
			set
			{
				_areaColor = value;
			}
		}

		bool _contour = false;
		public bool Contour
		{
			get
			{
				return _contour;
			}
			set
			{
				_contour = value;
			}
		}

		Int32 _contourColor = Utilities.GetColorNumber(Color.Black);
		public Int32 ContourColor //0...16777215
		{
			get
			{
				return _contourColor;
			}
			set
			{
				_contourColor = value;
			}
		}

		Single _vhs = (Single)(2);
		public Single Vhs //??????
		{
			get
			{
				return _vhs;
			}
			set
			{
				_vhs = value;
			}
		}

		Single _vht = (Single)(2);
		public Single Vht //??????
		{
			get
			{
				return _vht;
			}
			set
			{
				_vht = value;
			}
		}

		Int32 _vColor = Utilities.GetColorNumber(Color.Black); //??????
		public Int32 VColor //?????? //0...16777215
		{
			get
			{
				return _vColor;
			}
			set
			{
				_vColor = value;
			}
		}

		public RMCoverage()
		{
		}

		public void Save(BinaryWriter binaryWriter)
		{
			binaryWriter.Write(RadialRangeMaximum);
			binaryWriter.Write(AzimuthRangeMinimum);
			binaryWriter.Write(AzimuthRangeMaximum);
			binaryWriter.Write(AzimuthRangeStep);
			binaryWriter.Write(AntennaAzimuth);
			binaryWriter.Write(Utilities.PadRight(AntennaFile, 20, true));
			binaryWriter.Write((Int16)Threshold);
			binaryWriter.Write(Level);
			binaryWriter.Write(Utilities.ParseInt16(FillArea));
			binaryWriter.Write(AreaColor);
			binaryWriter.Write(Utilities.ParseInt16(Contour));
			binaryWriter.Write(ContourColor);
			binaryWriter.Write(Vhs);
			binaryWriter.Write(Vht);
			binaryWriter.Write(RadialRangeMinimum);
			binaryWriter.Write(VColor);
		}
	}
}