﻿/*
 * Author: G. Monz (DK7IO), 2012-04-29
 * This file is distributed without any warranty.
 * */

using System;
using System.IO;

namespace RadioMobile
{
	public enum NetPolarization
	{
		Horizontal = 0,
		Vertical = 1,
	}

	public enum NetClimate
	{
		Equatorial = 1,
		ContinentalSubTropical = 2,
		MaritimeSubTropical = 3,
		Desert = 4,
		ContinentalTemperate = 5,
		MaritimeTemperateOverLand = 6,
		MaritimeTemperateOverSea = 7,
	}

	public enum NetModeOfVariability
	{
		Spot = 0,
		Accidental = 1,
		Mobile = 2,
		Broadcast = 3,
	}

	public class RMNet
	{
		Single _minimumFrequency = (Single)(144);
		public Single MinimumFrequency //MHz
		{
			get
			{
				return _minimumFrequency;
			}
			set
			{
				_minimumFrequency = value;
			}
		}

		Single _maximumFrequency = (Single)(146);
		public Single MaximumFrequency //MHz
		{
			get
			{
				return _maximumFrequency;
			}
			set
			{
				_maximumFrequency = value;
			}
		}

		NetPolarization _polarization = NetPolarization.Horizontal;
		public NetPolarization Polarization
		{
			get
			{
				return _polarization;
			}
			set
			{
				_polarization = value;
			}
		}

		Single _relativeGroundPermittivity = (Single)(15);
		public Single RelativeGroundPermittivity
		{
			get
			{
				return _relativeGroundPermittivity;
			}
			set
			{
				_relativeGroundPermittivity = value;
			}
		}

		Single _groundConductivity = (Single)(0.005);
		public Single GroundConductivity //S/m
		{
			get
			{
				return _groundConductivity;
			}
			set
			{
				_groundConductivity = value;
			}
		}

		Single _surfaceRefractivity = (Single)(315);
		public Single SurfaceRefractivity //N-Units
		{
			get
			{
				return _surfaceRefractivity;
			}
			set
			{
				_surfaceRefractivity = value;
			}
		}

		NetClimate _climate = NetClimate.ContinentalTemperate;
		public NetClimate Climate
		{
			get
			{
				return _climate;
			}
			set
			{
				_climate = value;
			}
		}

		NetModeOfVariability _modeOfVariability = NetModeOfVariability.Broadcast;
		public NetModeOfVariability ModeOfVariability
		{
			get
			{
				return _modeOfVariability;
			}
			set
			{
				_modeOfVariability = value;
			}
		}

		Single _percentOfTime = (Single)(70);
		public Single PercentOfTime
		{
			get
			{
				return _percentOfTime;
			}
			set
			{
				_percentOfTime = value;
			}
		}

		Single _percentOfLocations = (Single)(70);
		public Single PercentOfLocations
		{
			get
			{
				return _percentOfLocations;
			}
			set
			{
				_percentOfLocations = value;
			}
		}

		Single _percentOfSituations = (Single)(70);
		public Single PercentOfSituations
		{
			get
			{
				return _percentOfSituations;
			}
			set
			{
				_percentOfSituations = value;
			}
		}

		Int16 _hops = 0;
		public Int16 Hops //?????
		{
			get
			{
				return _hops;
			}
			set
			{
				_hops = value;
			}
		}

		Int16 _topology = 256;
		public Int16 Topology //????????
		{
			get
			{
				return _topology;
			}
			set
			{
				_topology = value;
			}
		}

		String _name = "Net  1";
		public String Name //Length:=30
		{
			get
			{
				return _name;
			}
			set
			{
				_name = value;
			}
		}

		public RMNet()
		{
		}

		public RMNet(string name)
			: this()
		{
			Name = name;
		}

		public void Save(BinaryWriter binaryWriter)
		{
			binaryWriter.Write(MinimumFrequency);
			binaryWriter.Write(MaximumFrequency);
			binaryWriter.Write((Int16)Polarization);
			binaryWriter.Write(RelativeGroundPermittivity);
			binaryWriter.Write(GroundConductivity);
			binaryWriter.Write(SurfaceRefractivity);
			binaryWriter.Write((Int16)Climate);
			binaryWriter.Write((Int16)ModeOfVariability);
			binaryWriter.Write(PercentOfTime);
			binaryWriter.Write(PercentOfLocations);
			binaryWriter.Write(PercentOfSituations);
			binaryWriter.Write(Hops);
			binaryWriter.Write(Topology);
			binaryWriter.Write(Utilities.PadRight(Name, 30, true));
		}
	}
}